<?php
/* 
** ZABBIX
** Copyright (C) 2000-2005 SIA Zabbix
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
**/
?>
<?php
	global $TRANSLATION;

	$TRANSLATION=array(

	"S_DATE_FORMAT_YMDHMS"=>		"d M H:i:s",
	"S_DATE_FORMAT_YMD"=>			"d M Y",
	"S_HTML_CHARSET"=>			"GB2312",

//	actions.php
	"S_ACTIONS"=>				"",
	"S_ACTION_ADDED"=>			"Ӳ",
	"S_CANNOT_ADD_ACTION"=>			"޷Ӳ",
	"S_ACTION_UPDATED"=>			"²Action updated",
	"S_CANNOT_UPDATE_ACTION"=>		"޷²Cannot update action",
	"S_ACTION_DELETED"=>			"ɾAction deleted",
	"S_CANNOT_DELETE_ACTION"=>		"޷ɾCannot delete action",
	"S_SCOPE"=>				"Scope",
	"S_SEND_MESSAGE_TO"=>			"Ϣ",
	"S_WHEN_TRIGGER"=>			"When trigger",
	"S_DELAY"=>				"ӳ",
	"S_SUBJECT"=>				"",
	"S_ON"=>				"",
	"S_OFF"=>				"",
	"S_NO_ACTIONS_DEFINED"=>		"ûж",
	"S_NEW_ACTION"=>			"µĲ",
	"S_SINGLE_USER"=>			"û",
	"S_USER_GROUP"=>			"û",
	"S_GROUP"=>				"",
	"S_USER"=>				"û",
	"S_WHEN_TRIGGER_BECOMES"=>		"",
	"S_ON_OR_OFF"=>				"",
	"S_DELAY_BETWEEN_MESSAGES_IN_SEC"=>	"Ϣͼ()",
	"S_MESSAGE"=>				"Ϣ",
	"S_THIS_TRIGGER_ONLY"=>			"",
	"S_ALL_TRIGGERS_OF_THIS_HOST"=>		"д",
	"S_ALL_TRIGGERS"=>			"д",
	"S_USE_IF_TRIGGER_SEVERITY"=>		"Ȼߴʱʹô",
	"S_NOT_CLASSIFIED"=>			"δ",
	"S_INFORMATION"=>			"Ϣ",
	"S_WARNING"=>				"",
	"S_AVERAGE"=>				"Average",
	"S_HIGH"=>				"",
	"S_DISASTER"=>				"",

//	alarms.php
	"S_ALARMS"=>				"alarms",
	"S_ALARMS_SMALL"=>			"Alarms",
	"S_ALARMS_BIG"=>			"ALARMS",
	"S_SHOW_ONLY_LAST_100"=>		"ֻʾµ100",
	"S_SHOW_ALL"=>				"ʾ",
	"S_TIME"=>				"ʱ",
	"S_STATUS"=>				"״̬",
	"S_DURATION"=>				"ʱ",
	"S_SUM"=>				"Sum",
	"S_TRUE_BIG"=>				"TRUE",
	"S_FALSE_BIG"=>				"FALSE",
	"S_DISABLED_BIG"=>			"DISABLED",
	"S_UNKNOWN_BIG"=>			"UNKNOWN",

//	alerts.php
	"S_ALERT_HISTORY_SMALL"=>		"ʷ",
	"S_ALERT_HISTORY_BIG"=>			"¼",
	"S_ALERTS_BIG"=>			"ALERTS",
	"S_TYPE"=>				"",
	"S_RECIPIENTS"=>			"ռ",
	"S_ERROR"=>				"",
	"S_SENT"=>				"ѷ",
	"S_NOT_SENT"=>				"δ",
	"S_NO_ALERTS"=>				"ޱ",
	"S_SHOW_NEXT_100"=>			"100",
	"S_SHOW_PREVIOUS_100"=>			"ǰ100",

//	charts.php
	"S_CUSTOM_GRAPHS"=>			"Custom graphs",
	"S_GRAPHS_BIG"=>			"GRAPHS",
	"S_NO_GRAPHS_TO_DISPLAY"=>		"No graphs to display",
	"S_SELECT_GRAPH_TO_DISPLAY"=>		"ѡͼ",
	"S_PERIOD"=>				"Period",
	"S_1H"=>				"1h",
	"S_2H"=>				"2h",
	"S_4H"=>				"4h",
	"S_8H"=>				"8h",
	"S_12H"=>				"12h",
	"S_24H"=>				"24h",
	"S_WEEK_SMALL"=>			"week",
	"S_MONTH_SMALL"=>			"month",
	"S_YEAR_SMALL"=>			"year",
	"S_KEEP_PERIOD"=>			"ʱ",
	"S_ON_C"=>				"On",
	"S_OFF_C"=>				"Off",
	"S_MOVE"=>				"Move",
	"S_NAVIGATE"=>				"Navigate",
	"S_INCREASE"=>				"Increase",
	"S_DECREASE"=>				"Decrease",
	"S_NAVIGATE"=>				"Navigate",
	"S_RIGHT_DIR"=>				"Right",
	"S_LEFT_DIR"=>				"Left",
	"S_SELECT_GRAPH_DOT_DOT_DOT"=>		"ѡͼ...",

// Colors
	"S_BLACK"=>				"Black",
	"S_BLUE"=>				"Blue",
	"S_CYAN"=>				"Cyan",
	"S_DARK_BLUE"=>				"Dark blue",
	"S_DARK_GREEN"=>			"Dark green",
	"S_DARK_RED"=>				"Dark red",
	"S_DARK_YELLOW"=>			"Dark yellow",
	"S_GREEN"=>				"Green",
	"S_RED"=>				"Red",
	"S_WHITE"=>				"White",
	"S_YELLOW"=>				"Yellow",

//	config.php
	"S_CONFIGURATION_OF_ZABBIX"=>		"ZABBIX",
	"S_CONFIGURATION_OF_ZABBIX_BIG"=>	"ZABBIX",
	"S_CONFIGURATION_UPDATED"=>		"Configuration updated",
	"S_CONFIGURATION_WAS_NOT_UPDATED"=>	"Configuration was not updated",
	"S_ADDED_NEW_MEDIA_TYPE"=>		"Added new media type",
	"S_NEW_MEDIA_TYPE_WAS_NOT_ADDED"=>	"New media type was not added",
	"S_MEDIA_TYPE_UPDATED"=>		"Media type updated",
	"S_MEDIA_TYPE_WAS_NOT_UPDATED"=>	"Media type was not updated",
	"S_MEDIA_TYPE_DELETED"=>		"Media type deleted",
	"S_MEDIA_TYPE_WAS_NOT_DELETED"=>	"Media type was not deleted",
	"S_CONFIGURATION"=>			"ϵͳ",
	"S_DO_NOT_KEEP_ACTIONS_OLDER_THAN"=>	"Do not keep actions older than (in days)",
	"S_DO_NOT_KEEP_EVENTS_OLDER_THAN"=>	"Do not keep events older than (in days)",
	"S_MEDIA_TYPES_BIG"=>			"",
	"S_NO_MEDIA_TYPES_DEFINED"=>		"δ",
	"S_SMTP_SERVER"=>			"SMTP",
	"S_SMTP_HELO"=>				"SMTP HELO",
	"S_SMTP_EMAIL"=>			"SMTP",
	"S_SCRIPT_NAME"=>			"ű",
	"S_DELETE_SELECTED_MEDIA"=>		"Delete selected media?",
	"S_DELETE_SELECTED_IMAGE"=>		"Delete selected image?",
	"S_HOUSEKEEPER"=>			"Housekeeper",
	"S_MEDIA_TYPES"=>			"Media types",
	"S_ESCALATION_RULES"=>			"Escalation rules",
	"S_ESCALATION"=>			"Escalation",
	"S_ESCALATION_RULES_BIG"=>		"ESCALATION RULES",
	"S_NO_ESCALATION_RULES_DEFINED"=>	"No escalation rules defined",
	"S_NO_ESCALATION_DETAILS"=>		"No escalation details",
	"S_ESCALATION_DETAILS_BIG"=>		"ESCALATION DETAILS",
	"S_ESCALATION_ADDED"=>			"Escalation added",
	"S_ESCALATION_WAS_NOT_ADDED"=>		"Escalation was not added",
	"S_ESCALATION_RULE_ADDED"=>		"Escalation rule added",
	"S_ESCALATION_RULE_WAS_NOT_ADDED"=>	"Escalation rule was not added",
	"S_ESCALATION_RULE_UPDATED"=>		"Escalation rule updated",
	"S_ESCALATION_RULE_WAS_NOT_UPDATED"=>	"Escalation rule was not updated",
	"S_ESCALATION_RULE_DELETED"=>		"Escalation rule deleted",
	"S_ESCALATION_RULE_WAS_NOT_DELETED"=>	"Escalation rule was not deleted",
	"S_ESCALATION_UPDATED"=>		"Escalation updated",
	"S_ESCALATION_WAS_NOT_UPDATED"=>	"Escalation was not updated",
	"S_ESCALATION_DELETED"=>		"Escalation deleted",
	"S_ESCALATION_WAS_NOT_DELETED"=>	"Escalation was not deleted",
	"S_ESCALATION_RULE"=>			"Escalation rule",
	"S_DO"=>				"Do",
	"S_DEFAULT"=>				"Ĭ",
	"S_IS_DEFAULT"=>			"ΪĬ",
	"S_LEVEL"=>				"ȼ",
	"S_DELAY_BEFORE_ACTION"=>		"Delay before action",
	"S_IMAGES"=>				"Images",
	"S_IMAGE"=>				"Image",
	"S_IMAGES_BIG"=>			"IMAGES",
	"S_NO_IMAGES_DEFINED"=>			"No images defined",
	"S_BACKGROUND"=>			"Background",
	"S_UPLOAD"=>				"Upload",
	"S_IMAGE_ADDED"=>			"Image added",
	"S_CANNOT_ADD_IMAGE"=>			"Cannot add image",
	"S_IMAGE_DELETED"=>			"Image deleted",
	"S_CANNOT_DELETE_IMAGE"=>		"Cannot delete image",
	"S_IMAGE_UPDATED"=>			"Image updated",
	"S_CANNOT_UPDATE_IMAGE"=>		"Cannot update image",
	"S_UPDATE_SELECTED_IMAGE"=>		"Update selected image?",
	"S_PRIORITY"=>				"ȼ",
	"S_PATTERN"=>				"Pattern",
	"S_OTHER"=>				"Other",
	"S_OTHER_PARAMETERS"=>			"",
	"S_REFRESH_UNSUPPORTED_ITEMS"=>		"Refresh unsupported items (in sec)",

//	Latest values
	"S_LATEST_VALUES"=>			"",
	"S_NO_PERMISSIONS"=>			"Ȩ޲!",
	"S_LATEST_DATA_BIG"=>			"",
	"S_ALL_SMALL"=>				"all",
	"S_DESCRIPTION_LARGE"=>			"DESCRIPTION",
	"S_DESCRIPTION_SMALL"=>			"Description",
	"S_GRAPH"=>				"ͼʾ",
	"S_TREND"=>				"Trend",
	"S_COMPARE"=>				"Ա",

//	Footer
	"S_COPYRIGHT_BY"=>			"Copyright 2001-2006 by ",
	"S_CONNECTED_AS"=>			"Connected as",
	"S_SIA_ZABBIX"=>			"SIA Zabbix",

//	graph.php
	"S_CONFIGURATION_OF_GRAPH"=>		"ͼʾ",
	"S_CONFIGURATION_OF_GRAPH_BIG"=>	"ͼʾ",
	"S_ITEM_ADDED"=>			"Item added",
	"S_ITEM_UPDATED"=>			"Item updated",
	"S_SORT_ORDER_UPDATED"=>		"Sort order updated",
	"S_CANNOT_UPDATE_SORT_ORDER"=>		"Cannot update sort order",
	"S_DISPLAYED_PARAMETERS_BIG"=>		"ʾ",
	"S_SORT_ORDER"=>			"Sort order",
	"S_PARAMETER"=>				"",
	"S_COLOR"=>				"ɫ",
	"S_UP"=>				"Up",
	"S_DOWN"=>				"Down",
	"S_NEW_ITEM_FOR_THE_GRAPH"=>		"New item for the graph",
	"S_SORT_ORDER_1_100"=>			"Sort order (0->100)",
	"S_YAXIS_SIDE"=>			"Y axis side",
	"S_LEFT"=>				"",

//	graphs.php
	"S_CONFIGURATION_OF_GRAPHS"=>		"ͼʾ",
	"S_CONFIGURATION_OF_GRAPHS_BIG"=>	"ͼʾ",
	"S_GRAPH_ADDED"=>			"Graph added",
	"S_GRAPH_UPDATED"=>			"Graph updated",
	"S_CANNOT_UPDATE_GRAPH"=>		"Cannot update graph",
	"S_GRAPH_DELETED"=>			"Graph deleted",
	"S_CANNOT_DELETE_GRAPH"=>		"Cannot delete graph",
	"S_CANNOT_ADD_GRAPH"=>			"Cannot add graph",
	"S_ID"=>				"ID",
	"S_NO_GRAPHS_DEFINED"=>			"No graphs defined",
	"S_DELETE_GRAPH_Q"=>			"Delete graph?",
	"S_YAXIS_TYPE"=>			"Y axis type",
	"S_YAXIS_MIN_VALUE"=>			"YСֵ",
	"S_YAXIS_MAX_VALUE"=>			"Yֵ",
	"S_CALCULATED"=>			"Calculated",
	"S_FIXED"=>				"Fixed",

//	history.php
	"S_LAST_HOUR_GRAPH"=>			"һСʱ",
	"S_VALUES_OF_LAST_HOUR"=>		"һСʱ",
	"S_500_LATEST_VALUES"=>			"500ֵ",
	"S_VALUES_OF_SPECIFIED_PERIOD"=>	"Values of specified period",
	"S_VALUES_IN_PLAIN_TEXT_FORMAT"=>	"ıʽʾ",
	"S_TIMESTAMP"=>				"ʱ",
	"S_LOCAL"=>				"Local",
	"S_SOURCE"=>				"Source",

//	hosts.php
	"S_HOSTS"=>				"",
	"S_ITEMS"=>				"Ŀ",
	"S_TRIGGERS"=>				"",
	"S_GRAPHS"=>				"ͼʾ",
	"S_HOST_ADDED"=>			"",
	"S_CANNOT_ADD_HOST"=>			"޷",
	"S_ITEMS_ADDED"=>			"Ŀ",
	"S_CANNOT_ADD_ITEMS"=>			"޷Ŀ",
	"S_HOST_UPDATED"=>			"Ѹ",
	"S_CANNOT_UPDATE_HOST"=>		"޷",
	"S_HOST_STATUS_UPDATED"=>		"״̬Ѹ",
	"S_CANNOT_UPDATE_HOST_STATUS"=>		"޷״̬",
	"S_HOST_DELETED"=>			"ɾ",
	"S_CANNOT_DELETE_HOST"=>		"޷ɾ",
	"S_TEMPLATE_LINKAGE_ADDED"=>		"ģ",
	"S_CANNOT_ADD_TEMPLATE_LINKAGE"=>	"޷ģ",
	"S_TEMPLATE_LINKAGE_UPDATED"=>		"Template linkage updated",
	"S_CANNOT_UPDATE_TEMPLATE_LINKAGE"=>	"Cannot update template linkage",
	"S_TEMPLATE_LINKAGE_DELETED"=>		"Template linkage deleted",
	"S_CANNOT_DELETE_TEMPLATE_LINKAGE"=>	"Cannot delete template linkage",
	"S_CONFIGURATION_OF_HOSTS_AND_HOST_GROUPS"=>"",
	"S_HOST_GROUPS_BIG"=>			"HOST GROUPS",
	"S_NO_HOST_GROUPS_DEFINED"=>		"ûж",
	"S_NO_LINKAGES_DEFINED"=>		"ûж",
	"S_NO_HOSTS_DEFINED"=>			"ûж",
	"S_HOSTS_BIG"=>				"",
	"S_HOST"=>				"",
	"S_IP"=>				"IPַ",
	"S_PORT"=>				"˿",
	"S_MONITORED"=>				"",
	"S_NOT_MONITORED"=>			"δ",
	"S_UNREACHABLE"=>			"޷",
	"S_TEMPLATE"=>				"ģ",
	"S_DELETED"=>				"ɾ",
	"S_UNKNOWN"=>				"״̬δ֪",
	"S_GROUPS"=>				"",
	"S_NEW_GROUP"=>				"",
	"S_USE_IP_ADDRESS"=>			"ʹIPַ",
	"S_IP_ADDRESS"=>			"IPַ",
//	"S_USE_THE_HOST_AS_A_TEMPLATE"=>		"Use the host as a template",
	"S_USE_TEMPLATES_OF_THIS_HOST"=>	"Use templates of this host",
	"S_DELETE_SELECTED_HOST_Q"=>		"Delete selected host?",
	"S_GROUP_NAME"=>			"û",
	"S_HOST_GROUP"=>			"",
	"S_HOST_GROUPS"=>			"",
	"S_UPDATE"=>				"",
	"S_AVAILABILITY"=>			"Availability",
	"S_AVAILABLE"=>				"",
	"S_NOT_AVAILABLE"=>			"",
//	Host profiles
	"S_HOST_PROFILE"=>			"",
	"S_DEVICE_TYPE"=>			"豸",
	"S_OS"=>				"ϵͳ",
	"S_SERIALNO"=>				"SerialNo",
	"S_TAG"=>				"ǩ",
	"S_HARDWARE"=>				"Ӳ",
	"S_SOFTWARE"=>				"",
	"S_CONTACT"=>				"ϵ",
	"S_LOCATION"=>				"λ",
	"S_NOTES"=>				"ע",
	"S_MACADDRESS"=>			"MACַ",
	"S_PROFILE_ADDED"=>			"",
	"S_CANNOT_ADD_PROFILE"=>		"޷",
	"S_PROFILE_UPDATED"=>			"Ѹ",
	"S_CANNOT_UPDATE_PROFILE"=>		"޷",
	"S_PROFILE_DELETED"=>			"ɾ",
	"S_CANNOT_DELETE_PROFILE"=>		"޷ɾ",
	"S_ADD_TO_GROUP"=>			"ӵ",
	"S_DELETE_FROM_GROUP"=>			"ɾ",
	"S_UPDATE_IN_GROUP"=>			"",
	"S_DELETE_SELECTED_HOSTS_Q"=>		"ɾѡ?",
	"S_DISABLE_SELECTED_HOSTS_Q"=>		"Disable selected hosts?",
	"S_ACTIVATE_SELECTED_HOSTS_Q"=>		"Activate selected hosts?",
	"S_SELECT_HOST_TEMPLATE_FIRST"=>	"Select host template first",

//	items.php
	"S_CONFIGURATION_OF_ITEMS"=>		"Ŀ",
	"S_CONFIGURATION_OF_ITEMS_BIG"=>	"üĿ",
	"S_CANNOT_UPDATE_ITEM"=>		"Cannot update item",
	"S_STATUS_UPDATED"=>			"״̬Ѹ",
	"S_CANNOT_UPDATE_STATUS"=>		"Cannot update status",
	"S_CANNOT_ADD_ITEM"=>			"Cannot add item",
	"S_ITEM_DELETED"=>			"Item deleted",
	"S_CANNOT_DELETE_ITEM"=>		"Cannot delete item",
	"S_ITEMS_DELETED"=>			"Items deleted",
	"S_CANNOT_DELETE_ITEMS"=>		"Cannot delete items",
	"S_ITEMS_ACTIVATED"=>			"Items activated",
	"S_CANNOT_ACTIVATE_ITEMS"=>		"Cannot activate items",
	"S_ITEMS_DISABLED"=>			"Items disabled",
	"S_CANNOT_DISABLE_ITEMS"=>		"Cannot disable items",
	"S_SERVERNAME"=>			"Server Name",
	"S_KEY"=>				"Keyֵ",
	"S_DESCRIPTION"=>			"",
	"S_UPDATE_INTERVAL"=>			"¼s",
	"S_HISTORY"=>				"¼d",
	"S_TRENDS"=>				"Trends",
	"S_SHORT_NAME"=>			"Short name",
	"S_ZABBIX_AGENT"=>			"ZABBIX agent",
	"S_ZABBIX_AGENT_ACTIVE"=>		"ZABBIX agent (active)",
	"S_SNMPV1_AGENT"=>			"SNMPv1 agent",
	"S_ZABBIX_TRAPPER"=>			"ZABBIX trapper",
	"S_SIMPLE_CHECK"=>			"Simple check",
	"S_SNMPV2_AGENT"=>			"SNMPv2 agent",
	"S_SNMPV3_AGENT"=>			"SNMPv3 agent",
	"S_ZABBIX_INTERNAL"=>			"ZABBIX internal",
	"S_ZABBIX_UNKNOWN"=>			"δ֪",
	"S_ACTIVE"=>				"Ծ",
	"S_NOT_ACTIVE"=>			"Ծ",
	"S_NOT_SUPPORTED"=>			"֧",
	"S_ACTIVATE_SELECTED_ITEMS_Q"=>		"ѡеĿ?",
	"S_DISABLE_SELECTED_ITEMS_Q"=>		"ȡѡеĿ?",
	"S_DELETE_SELECTED_ITEMS_Q"=>		"ɾѡеĿ?",
	"S_EMAIL"=>				"Email",
	"S_SCRIPT"=>				"Script",
	"S_UNITS"=>				"λUnits",
	"S_MULTIPLIER"=>			"Multiplier",
	"S_UPDATE_INTERVAL_IN_SEC"=>		"ݸ¼()",
	"S_KEEP_HISTORY_IN_DAYS"=>		"ݱ",
	"S_KEEP_TRENDS_IN_DAYS"=>		"Keep trends (in days)",
	"S_TYPE_OF_INFORMATION"=>		"",
	"S_STORE_VALUE"=>			"Store value",
	"S_NUMERIC"=>				"ֵ",
	"S_CHARACTER"=>				"ַ",
	"S_LOG"=>				"־",
	"S_AS_IS"=>				"As is",
	"S_DELTA_SPEED_PER_SECOND"=>		"Delta (speed per second)",
	"S_DELTA_SIMPLE_CHANGE"=>		"Delta (simple change)",
	"S_ITEM"=>				"Item",
	"S_SNMP_COMMUNITY"=>			"SNMP community",
	"S_SNMP_OID"=>				"SNMP OID",
	"S_SNMP_PORT"=>				"SNMP port",
	"S_ALLOWED_HOSTS"=>			"Allowed hosts",
	"S_SNMPV3_SECURITY_NAME"=>		"SNMPv3 security name",
	"S_SNMPV3_SECURITY_LEVEL"=>		"SNMPv3 security level",
	"S_SNMPV3_AUTH_PASSPHRASE"=>		"SNMPv3 auth passphrase",
	"S_SNMPV3_PRIV_PASSPHRASE"=>		"SNMPv3 priv passphrase",
	"S_CUSTOM_MULTIPLIER"=>			"Custom multiplier",
	"S_DO_NOT_USE"=>			"Do not use",
	"S_USE_MULTIPLIER"=>			"ʹó˷",
	"S_SELECT_HOST_DOT_DOT_DOT"=>		"ѡ...",
	"S_LOG_TIME_FORMAT"=>			"Log time format",

//	latestalarms.php
	"S_LATEST_EVENTS"=>			"±",
	"S_HISTORY_OF_EVENTS_BIG"=>		"ϵͳϢ",

//	latest.php
	"S_LAST_CHECK"=>			"¼",
	"S_LAST_CHECK_BIG"=>			"LAST CHECK",
	"S_LAST_VALUE"=>			"",

//	sysmap.php
	"S_LABEL"=>				"Label",
	"S_X"=>					"X",
	"S_Y"=>					"Y",
	"S_ICON"=>				"Icon",
	"S_HOST_1"=>				"Host 1",
	"S_HOST_2"=>				"Host 2",
	"S_LINK_STATUS_INDICATOR"=>		"Link status indicator",
	"S_CONFIGURATION_OF_NETWORK_MAPS"=>	"ϵͳͼ",

//	map.php
	"S_OK_BIG"=>				"OK",
	"S_PROBLEMS_SMALL"=>			"problems",
	"S_ZABBIX_URL"=>			"http://www.zabbix.com",

//	maps.php
	"S_NETWORK_MAPS"=>			"ṹͼ",
	"S_NETWORK_MAPS_BIG"=>			"ṹ",
	"S_NO_MAPS_TO_DISPLAY"=>		"ûнṹͼʾ",
	"S_SELECT_MAP_TO_DISPLAY"=>		"ѡṹͼ",
	"S_SELECT_MAP_DOT_DOT_DOT"=>		"ѡ...",
	"S_BACKGROUND_IMAGE"=>			"ͼƬ",
	"S_ICON_LABEL_TYPE"=>			"Icon label type",
	"S_HOST_LABEL"=>			"Host label",
	"S_HOST_NAME"=>				"Host name",
	"S_STATUS_ONLY"=>			"Status only",
	"S_NOTHING"=>				"Nothing",

//	media.php
	"S_MEDIA"=>				"",
	"S_MEDIA_BIG"=>				"Ϣ",
	"S_MEDIA_ACTIVATED"=>			"Ѽ",
	"S_CANNOT_ACTIVATE_MEDIA"=>		"޷",
	"S_MEDIA_DISABLED"=>			"ͣ",
	"S_CANNOT_DISABLE_MEDIA"=>		"޷ͣ",
	"S_MEDIA_ADDED"=>			"",
	"S_CANNOT_ADD_MEDIA"=>			"޷ӽ",
	"S_MEDIA_UPDATED"=>			"",
	"S_CANNOT_UPDATE_MEDIA"=>		"޷",
	"S_MEDIA_DELETED"=>			"ɾ",
	"S_CANNOT_DELETE_MEDIA"=>		"޷ɾ",
	"S_SEND_TO"=>				"ռ",
	"S_WHEN_ACTIVE"=>			"ʱ",
	"S_NO_MEDIA_DEFINED"=>			"ûж",
	"S_NEW_MEDIA"=>				"New media",
	"S_USE_IF_SEVERITY"=>			"Use if severity",
	"S_DELETE_SELECTED_MEDIA_Q"=>		"Delete selected media?",

//	Menu
	"S_MENU_LATEST_VALUES"=>		"",
	"S_MENU_TRIGGERS"=>			"",
	"S_MENU_QUEUE"=>			"",
	"S_MENU_ALARMS"=>			"ALARMS",
	"S_MENU_ALERTS"=>			"ALERTS",
	"S_MENU_NETWORK_MAPS"=>			"ṹͼ",
	"S_MENU_GRAPHS"=>			"GRAPHS",
	"S_MENU_SCREENS"=>			"SCREENS",
	"S_MENU_IT_SERVICES"=>			"IT",
	"S_MENU_HOME"=>				"HOME",
	"S_MENU_ABOUT"=>			"ABOUT",
	"S_MENU_STATUS_OF_ZABBIX"=>		"ZABBIXϵͳ״̬",
	"S_MENU_AVAILABILITY_REPORT"=>		"AVAILABILITY REPORT",
	"S_MENU_CONFIG"=>			"CONFIG",
	"S_MENU_USERS"=>			"û",
	"S_MENU_HOSTS"=>			"",
	"S_MENU_ITEMS"=>			"ITEMS",
	"S_MENU_AUDIT"=>			"AUDIT",

//	overview.php
	"S_SELECT_GROUP_DOT_DOT_DOT"=>		"Select group ...",
	"S_OVERVIEW"=>				"",
	"S_OVERVIEW_BIG"=>			"",
	"S_EXCL"=>				"!",
	"S_DATA"=>				"",

//	queue.php
	"S_QUEUE_BIG"=>				"QUEUE",
	"S_QUEUE_OF_ITEMS_TO_BE_UPDATED_BIG"=>	"ѾµĶ",
	"S_NEXT_CHECK"=>			"Next check",
	"S_THE_QUEUE_IS_EMPTY"=>		"The queue is empty",
	"S_TOTAL"=>				"ϼ",
	"S_COUNT"=>				"",
	"S_5_SECONDS"=>				"5",
	"S_10_SECONDS"=>			"10",
	"S_30_SECONDS"=>			"30",
	"S_1_MINUTE"=>				"1",
	"S_5_MINUTES"=>				"5",
	"S_MORE_THAN_5_MINUTES"=>		"5",

//	report1.php
	"S_STATUS_OF_ZABBIX"=>			"ZABBIX״̬",
	"S_STATUS_OF_ZABBIX_BIG"=>		"ZABBIXϵͳ״̬",
	"S_VALUE"=>				"ֵ",
	"S_ZABBIX_SERVER_IS_RUNNING"=>		"ZABBIX server ״̬",
	"S_NUMBER_OF_VALUES_STORED"=>		"ѱϢ",
	"S_NUMBER_OF_TRENDS_STORED"=>		"ѱtrends",
	"S_NUMBER_OF_ALARMS"=>			"alarmsʾ",
	"S_NUMBER_OF_ALERTS"=>			"alerts",
	"S_NUMBER_OF_TRIGGERS_ENABLED_DISABLED"=>"(Ծ/Ծ)",
	"S_NUMBER_OF_ITEMS_ACTIVE_TRAPPER"=>	"ͳƵĿ (Ծ/trapper/Ծ/֧)",
	"S_NUMBER_OF_USERS"=>			"ZABBIXϵͳû",
	"S_NUMBER_OF_HOSTS_MONITORED"=>		"(/δ/ģ/ɾ)",
	"S_YES"=>				"Yes",
	"S_NO"=>				"No",

//	report2.php
	"S_AVAILABILITY_REPORT"=>		"ͳ",
	"S_AVAILABILITY_REPORT_BIG"=>		"ϵͳͳ",
	"S_SHOW"=>				"ʾ",
	"S_TRUE"=>				"",
	"S_FALSE"=>				"",

//	report3.php
	"S_IT_SERVICES_AVAILABILITY_REPORT_BIG"=>	"ITԱ",
	"S_FROM"=>				"From",
	"S_TILL"=>				"Till",
	"S_OK"=>				"Ok",
	"S_PROBLEMS"=>				"Problems",
	"S_PERCENTAGE"=>			"ٷֱ",
	"S_SLA"=>				"SLA",
	"S_DAY"=>				"",
	"S_MONTH"=>				"",
	"S_YEAR"=>				"",
	"S_DAILY"=>				"ÿ",
	"S_WEEKLY"=>				"ÿ",
	"S_MONTHLY"=>				"ÿ",
	"S_YEARLY"=>				"ÿ",

//	screenconf.php
	"S_SCREENS"=>				"ý",
	"S_SCREEN"=>				"",
	"S_CONFIGURATION_OF_SCREENS_BIG"=>	"ûʾ",
	"S_CONFIGURATION_OF_SCREENS"=>		"ʾ",
	"S_SCREEN_ADDED"=>			"",
	"S_CANNOT_ADD_SCREEN"=>			"޷ӽ",
	"S_SCREEN_UPDATED"=>			"Ѹ",
	"S_CANNOT_UPDATE_SCREEN"=>		"޷½",
	"S_SCREEN_DELETED"=>			"ɾ",
	"S_CANNOT_DELETE_SCREEN"=>		"޷ɾ",
	"S_COLUMNS"=>				"",
	"S_ROWS"=>				"",
	"S_NO_SCREENS_DEFINED"=>		"No screens defined",
	"S_DELETE_SCREEN_Q"=>			"Delete screen?",
	"S_CONFIGURATION_OF_SCREEN_BIG"=>	"CONFIGURATION OF SCREEN",
	"S_SCREEN_CELL_CONFIGURATION"=>		"Screen cell configuration",
	"S_RESOURCE"=>				"Դ",
	"S_SIMPLE_GRAPH"=>			"Simple graph",
	"S_GRAPH_NAME"=>			"ͼ",
	"S_WIDTH"=>				"",
	"S_HEIGHT"=>				"",
	"S_EMPTY"=>				"Empty",

//	screenedit.php
	"S_MAP"=>				"Map",
	"S_PLAIN_TEXT"=>			"ı",
	"S_COLUMN_SPAN"=>			"Column span",
	"S_ROW_SPAN"=>				"Row span",

//	screens.php
	"S_CUSTOM_SCREENS"=>			"û",
	"S_SCREENS_BIG"=>			"û",
	"S_NO_SCREENS_TO_DISPLAY"=>		"No screens to display",
	"S_SELECT_SCREEN_TO_DISPLAY"=>		"ѡҪʾͼ",
	"S_SELECT_SCREEN_DOT_DOT_DOT"=>		"ѡ...",

//	services.php
	"S_IT_SERVICES"=>			"IT״̬",
	"S_SERVICE_UPDATED"=>			"Service updated",
	"S_CANNOT_UPDATE_SERVICE"=>		"Cannot update service",
	"S_SERVICE_ADDED"=>			"Service added",
	"S_CANNOT_ADD_SERVICE"=>		"Cannot add service",
	"S_LINK_ADDED"=>			"Link added",
	"S_CANNOT_ADD_LINK"=>			"Cannot add link",
	"S_SERVICE_DELETED"=>			"Service deleted",
	"S_CANNOT_DELETE_SERVICE"=>		"Cannot delete service",
	"S_LINK_DELETED"=>			"Link deleted",
	"S_CANNOT_DELETE_LINK"=>		"Cannot delete link",
	"S_STATUS_CALCULATION"=>		"״̬ͳ",
	"S_STATUS_CALCULATION_ALGORITHM"=>	"Status calculation algorithm",
	"S_NONE"=>				"None",
	"S_MAX_OF_CHILDS"=>			"MAX of childs",
	"S_MIN_OF_CHILDS"=>			"MIN of childs",
	"S_SERVICE_1"=>				"Service 1",
	"S_SERVICE_2"=>				"Service 2",
	"S_SOFT_HARD_LINK"=>			"Soft/hard link",
	"S_SOFT"=>				"Soft",
	"S_HARD"=>				"Hard",
	"S_DO_NOT_CALCULATE"=>			"Do not calculate",
	"S_MAX_BIG"=>				"MAX",
	"S_MIN_BIG"=>				"MIN",
	"S_SHOW_SLA"=>				"Show SLA",
	"S_ACCEPTABLE_SLA_IN_PERCENT"=>		"Acceptabe SLA (in %)",
	"S_LINK_TO_TRIGGER_Q"=>			"Link to trigger?",
	"S_SORT_ORDER_0_999"=>			"Sort order (0->999)",
	"S_DELETE_SERVICE_Q"=>			"S_DELETE_SERVICE_Q",
	"S_LINK_TO"=>				"",
	"S_SOFT_LINK_Q"=>			"?",
	"S_ADD_SERVER_DETAILS"=>		"Add server details",
	"S_TRIGGER"=>				"Trigger",
	"S_SERVER"=>				"Server",
	"S_DELETE"=>				"Delete",
	"S_DELETE_SELECTED_SERVICES"=>		"Delete selected services?",
	"S_SERVICES_DELETED"=>			"Services deleted",
	"S_CANNOT_DELETE_SERVICES"=>		"Cannot delete services",

//	srv_status.php
	"S_IT_SERVICES_BIG"=>			"IT",
	"S_SERVICE"=>				"",
	"S_REASON"=>				"Reason",
	"S_SLA_LAST_7_DAYS"=>			"SLA (last 7 days)",
	"S_PLANNED_CURRENT_SLA"=>		"Planned/current SLA",
	"S_TRIGGER_BIG"=>			"TRIGGER",

//	triggers.php
	"S_CONFIGURATION_OF_TRIGGERS"=>		"ô",
	"S_CONFIGURATION_OF_TRIGGERS_BIG"=>	"",
	"S_DEPENDENCY_ADDED"=>			"Dependency added",
	"S_CANNOT_ADD_DEPENDENCY"=>		"Cannot add dependency",
	"S_TRIGGERS_UPDATED"=>			"Ѹ",
	"S_CANNOT_UPDATE_TRIGGERS"=>		"޷´",
	"S_TRIGGERS_DISABLED"=>			"ȡ",
	"S_CANNOT_DISABLE_TRIGGERS"=>		"޷ȡ",
	"S_TRIGGERS_DELETED"=>			"ɾ",
	"S_CANNOT_DELETE_TRIGGERS"=>		"޷ɾ",
	"S_TRIGGER_DELETED"=>			"ɾ",
	"S_CANNOT_DELETE_TRIGGER"=>		"޷ɾ",
	"S_INVALID_TRIGGER_EXPRESSION"=>	"ʽЧ",
	"S_TRIGGER_ADDED"=>			"",
	"S_CANNOT_ADD_TRIGGER"=>		"޷Ӵ",
	"S_SEVERITY"=>				"ʾ",
	"S_EXPRESSION"=>			"ʽ",
	"S_DISABLED"=>				"Ծ",
	"S_ENABLED"=>				"Ծ",
	"S_ENABLE_SELECTED_TRIGGERS_Q"=>	"ѡеĴ?",
	"S_DISABLE_SELECTED_TRIGGERS_Q"=>	"ȡѡеĴ?",
	"S_CHANGE"=>				"",
	"S_TRIGGER_UPDATED"=>			"Ѹ",
	"S_CANNOT_UPDATE_TRIGGER"=>		"޷´",
	"S_DEPENDS_ON"=>			"Depends on",

//	tr_comments.php
	"S_TRIGGER_COMMENTS"=>			"Trigger comments",
	"S_TRIGGER_COMMENTS_BIG"=>		"TRIGGER COMMENTS",
	"S_COMMENT_UPDATED"=>			"Comment updated",
	"S_CANNOT_UPDATE_COMMENT"=>		"Cannot update comment",
	"S_ADD"=>				"Add",

//	tr_status.php
	"S_STATUS_OF_TRIGGERS"=>		"״̬",
	"S_STATUS_OF_TRIGGERS_BIG"=>		"״̬",
	"S_SHOW_ONLY_TRUE"=>			"Show only true",
	"S_HIDE_ACTIONS"=>			"ز",
	"S_SHOW_ACTIONS"=>			"ʾ",
	"S_SHOW_ALL_TRIGGERS"=>			"ʾд",
	"S_HIDE_DETAILS"=>			"ϸ",
	"S_SHOW_DETAILS"=>			"ʾϸ",
	"S_SELECT"=>				"",
	"S_HIDE_SELECT"=>			"",
	"S_TRIGGERS_BIG"=>			"",
	"S_DESCRIPTION_BIG"=>			"ϸ",
	"S_SEVERITY_BIG"=>			"ʾ",
	"S_LAST_CHANGE_BIG"=>			"ϴ޸",
	"S_LAST_CHANGE"=>			"ϴ޸",
	"S_COMMENTS"=>				"ע",

//	users.php
	"S_USERS"=>				"û",
	"S_USER_ADDED"=>			"û",
	"S_CANNOT_ADD_USER"=>			"Cannot add user",
	"S_CANNOT_ADD_USER_BOTH_PASSWORDS_MUST"=>"Cannot add user. Both passwords must be equal.",
	"S_USER_DELETED"=>			"User deleted",
	"S_CANNOT_DELETE_USER"=>		"Cannot delete user",
	"S_PERMISSION_DELETED"=>		"Permission deleted",
	"S_CANNOT_DELETE_PERMISSION"=>		"Cannot delete permission",
	"S_PERMISSION_ADDED"=>			"Permission added",
	"S_CANNOT_ADD_PERMISSION"=>		"Cannot add permission",
	"S_USER_UPDATED"=>			"User updated",
	"S_CANNOT_UPDATE_USER"=>		"Cannot update user",
	"S_CANNOT_UPDATE_USER_BOTH_PASSWORDS"=>	"Cannot update user. Both passwords must be equal.",
	"S_GROUP_ADDED"=>			"Group added",
	"S_CANNOT_ADD_GROUP"=>			"Cannot add group",
	"S_GROUP_UPDATED"=>			"Group updated",
	"S_CANNOT_UPDATE_GROUP"=>		"Cannot update group",
	"S_GROUP_DELETED"=>			"Group deleted",
	"S_CANNOT_DELETE_GROUP"=>		"Cannot delete group",
	"S_CONFIGURATION_OF_USERS_AND_USER_GROUPS"=>"ûû",
	"S_USER_GROUPS_BIG"=>			"û",
	"S_USERS_BIG"=>				"û",
	"S_USER_GROUPS"=>			"û",
	"S_MEMBERS"=>				"Ա",
	"S_TEMPLATES"=>				"Templates",
	"S_HOSTS_TEMPLATES_LINKAGE"=>		"Hosts/templates linkage",
	"S_CONFIGURATION_OF_TEMPLATES_LINKAGE"=>"CONFIGURATION OF TEMPLATES LINKAGE",
	"S_LINKED_TEMPLATES_BIG"=>		"LINKED TEMPLATES",
	"S_NO_USER_GROUPS_DEFINED"=>		"δû",
	"S_ALIAS"=>				"½",
	"S_NAME"=>				"",
	"S_SURNAME"=>				"",
	"S_IS_ONLINE_Q"=>			"Ƿ?",
	"S_NO_USERS_DEFINED"=>			"ûжû",
	"S_PERMISSION"=>			"Permission",
	"S_RIGHT"=>				"Ȩ",
	"S_RESOURCE_NAME"=>			"Resource name",
	"S_READ_ONLY"=>				"ֻ",
	"S_READ_WRITE"=>			"д",
	"S_HIDE"=>				"",
	"S_PASSWORD"=>				"",
	"S_PASSWORD_ONCE_AGAIN"=>		"ȷ",
	"S_URL_AFTER_LOGIN"=>			"¼",
	"S_AUTO_LOGOUT_IN_SEC"=>		"Զ˳(0 Զ)",
	"S_SCREEN_REFRESH"=>                    "Զˢм(s)",

//	audit.php
	"S_AUDIT_LOG"=>				"־",
	"S_AUDIT_LOG_BIG"=>			"־",
	"S_ACTION"=>				"",
	"S_DETAILS"=>				"ϸ",
	"S_UNKNOWN_ACTION"=>			"δ֪",
	"S_ADDED"=>				"",
	"S_UPDATED"=>				"",
	"S_LOGGED_IN"=>				"¼/˳",
	"S_LOGGED_OUT"=>			"˳",
	"S_MEDIA_TYPE"=>			"",
	"S_GRAPH_ELEMENT"=>			"Graph element",
	"S_UNKNOWN_RESOURCE"=>			"δ֪Դ",

//	profile.php
	"S_USER_PROFILE_BIG"=>			"USER PROFILE",
	"S_USER_PROFILE"=>			"User profile",
	"S_LANGUAGE"=>				"Language",
	"S_ENGLISH_GB"=>			"English (GB)",
	"S_JAPANESE_JP"=>			"Chinese (CN)",
	"S_FRENCH_FR"=>				"French (FR)",
	"S_GERMAN_DE"=>				"German (DE)",
	"S_ITALIAN_IT"=>			"Italian (IT)",
	"S_LATVIAN_LV"=>			"Latvian (LV)",
	"S_RUSSIAN_RU"=>			"Russian (RU)",
	"S_SPANISH_SP"=>			"Spanish (SP)",
	
//	index.php
	"S_ZABBIX_BIG"=>			"ZABBIX",

//	hostprofiles.php
	"S_HOST_PROFILES"=>			"Host profiles",
	"S_HOST_PROFILES_BIG"=>			"ѡλ=>",

//	bulkloader.php
	"S_MENU_BULKLOADER"=>			"",
	"S_BULKLOADER_MAIN"=>			": Main Page",
	"S_BULKLOADER_HOSTS"=>			": Hosts",
	"S_BULKLOADER_ITEMS"=>			": Items",
	"S_BULKLOADER_USERS"=>			": Users",
	"S_BULKLOADER_TRIGGERS"=>		": Triggers",
	"S_BULKLOADER_ACTIONS"=>		": Actions",
	"S_BULKLOADER_ITSERVICES"=>		": IT Services",

	"S_BULKLOADER_IMPORT_HOSTS"=>		"",
	"S_BULKLOADER_IMPORT_ITEMS"=>		"Import Items",
	"S_BULKLOADER_IMPORT_USERS"=>		"Import Users",
	"S_BULKLOADER_IMPORT_TRIGGERS"=>	"Import Triggers",
	"S_BULKLOADER_IMPORT_ACTIONS"=>		"Import Actions",
	"S_BULKLOADER_IMPORT_ITSERVICES"=>	"Import IT Services",

//	Menu

	"S_HELP"=>				"",
	"S_PROFILE"=>				"",
	"S_MONITORING"=>			"״̬ͳ",
	"S_CONFIGURATION_MANAGEMENT"=>		"",
	"S_QUEUE"=>				"",
	"S_EVENTS"=>				"¼",
	"S_MAPS"=>				"ϵͳ",
	"S_REPORTS"=>				"ϵͳ",
	"S_GENERAL"=>				"ժҪ",
	"S_AUDIT"=>				"",
	"S_LOGIN"=>				"¼/˳",
	"S_LATEST_DATA"=>			"",
	);
?>
